pub struct WifiCsiInfo<'a> { /* private fields */ }csi and unstable only.Expand description
CSI (Channel State Information) packet metadata and associated packet details.
This structure contains the raw CSI data, along with necessary metadata from the received Wi-Fi packet (MAC addresses, sequence number, packet headers).
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'a> WifiCsiInfo<'_>
impl<'a> WifiCsiInfo<'_>
Sourcepub fn rssi(&self) -> i8
pub fn rssi(&self) -> i8
Received Signal Strength Indicator (RSSI) of the packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rate(&self) -> u8
pub fn rate(&self) -> u8
Data rate of the packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn noise_floor(&self) -> i8
pub fn noise_floor(&self) -> i8
Noise floor in dBm of Radio Frequency Module(RF).
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn channel(&self) -> u8
pub fn channel(&self) -> u8
Primary channel on which this packet is received.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn secondary_channel(&self) -> SecondaryChannel
pub fn secondary_channel(&self) -> SecondaryChannel
SecondaryChannel on which this packet is received.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn timestamp(&self) -> Instant
pub fn timestamp(&self) -> Instant
The local time in microseconds when this packet is received. It is precise only if modem sleep or light sleep is not enabled.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn signal_length(&self) -> u16
pub fn signal_length(&self) -> u16
The length of the reception MPDU.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_state(&self) -> u8
pub fn rx_state(&self) -> u8
State of the packet. 0: no error; others: failure.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_match1(&self) -> bool
pub fn rx_match1(&self) -> bool
Indicate whether the reception frame is from interface 1.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_match2(&self) -> bool
pub fn rx_match2(&self) -> bool
Indicate whether the reception frame is from interface 2.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_match3(&self) -> bool
pub fn rx_match3(&self) -> bool
Indicate whether the reception frame is from interface 3.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn he_siga1(&self) -> u32
pub fn he_siga1(&self) -> u32
HE-SIGA1 or HT-SIG.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_end_state(&self) -> u8
pub fn rx_end_state(&self) -> u8
Reception state, 0: successful, others: failure.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn he_siga2(&self) -> u16
pub fn he_siga2(&self) -> u16
HE-SIGA2.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn is_group(&self) -> bool
pub fn is_group(&self) -> bool
Indicate whether the reception is a group addressed frame.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_channel_estimate_length(&self) -> u32
pub fn rx_channel_estimate_length(&self) -> u32
The length of the channel information.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_channel_estimate_info_valid(&self) -> bool
pub fn rx_channel_estimate_info_valid(&self) -> bool
Indicate the channel information is valid.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn cur_bb_format(&self) -> u8
pub fn cur_bb_format(&self) -> u8
The format of the reception frame.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn dump_length(&self) -> u32
pub fn dump_length(&self) -> u32
The length of the reception MPDU excluding the FCS.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn mac(&self) -> &[u8; 6]
pub fn mac(&self) -> &[u8; 6]
Source MAC address of the CSI data.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn destination_mac(&self) -> &[u8; 6]
pub fn destination_mac(&self) -> &[u8; 6]
Destination MAC address of the CSI data.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn first_word_invalid(&self) -> bool
pub fn first_word_invalid(&self) -> bool
First four bytes of the CSI data is invalid or not, true indicates the first four bytes is invalid due to hardware limitation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn buf(&self) -> &[i8]
pub fn buf(&self) -> &[i8]
Valid buffer of CSI data.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn header(&self) -> &[u8]
pub fn header(&self) -> &[u8]
Header of the wifi packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn payload(&self) -> &[u8]
pub fn payload(&self) -> &[u8]
Payload of the wifi packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn rx_sequence(&self) -> u16
pub fn rx_sequence(&self) -> u16
Rx sequence number of the wifi packet.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.